const DailyRotateFile = require("winston-daily-rotate-file");
const fs = require("fs");

const get_log_format = require("./get_log_format.js");
const on_rotation = require("./on_rotation.js");

const LOGS_PATH = process.env.LOGS_PATH;
const LOG_LEVEL = process.env.NODE_LOG_LEVEL || "debug";

if (!fs.existsSync(LOGS_PATH)) {
	// Create the directory if it does not exist
	fs.mkdirSync(LOGS_PATH);
}

function get_errors_log_transport(source) {
	const errors_log_transport = new DailyRotateFile({
		format: get_log_format(source),
		level: "error",
		filename: "errors.log.%DATE%",
		dirname: LOGS_PATH,
		datePattern: "DD-MM-YYYY",
		// maxsize: '1000',
		maxFiles: "14d"
		// zippedArchive: true
	});

	errors_log_transport.on("rotate", on_rotation);

	return errors_log_transport;
}

function get_combined_log_transport(source) {
	const combined_log_transport = new DailyRotateFile({
		format: get_log_format(source),
		level: LOG_LEVEL,
		filename: "combined.log.%DATE%",
		dirname: LOGS_PATH,
		datePattern: "DD-MM-YYYY:HH",
		// maxsize: '1000',
		maxFiles: "14d"
		// zippedArchive: true
	});

	combined_log_transport.on("rotate", on_rotation);

	return combined_log_transport;
}

module.exports = {
	get_combined_log_transport: get_combined_log_transport,
	get_errors_log_transport: get_errors_log_transport
};
